@@ -583,8 +583,10 @@ Logger::~Logger()
 
   // Cleanup appenders
   QMutexLocker appendersLocker(&d->loggerMutex);
-  qDeleteAll(d->appenders);
-  qDeleteAll(d->categoryAppenders);
+
+  QSet<AbstractAppender*> appenderList;
+  appenderList += d->appenders.toSet() += d->categoryAppenders.values().toSet();
+  qDeleteAll(appenderList);
 
   // Cleanup device
   delete d->logDevice;
@@ -746,7 +748,7 @@ void Logger::registerCategoryAppender(const QString& category, AbstractAppender*
 
   QMutexLocker locker(&d->loggerMutex);
 
-  if (!d->categoryAppenders.values().contains(appender))
+  if (!d->categoryAppenders.contains(category, appender))
     d->categoryAppenders.insert(category, appender);
   else
     std::cerr << "Trying to register appender that was already registered" << std::endl;
