@@ -145,7 +145,7 @@ public:
  * \brief write key/value to storage.
  *
  * \fn void DSettingsBackend::optionChanged(const QString &key, const QVariant &value);
- * \brief emited when option value changed.
+ * \brief emitted when option value changed.
  *
  * \fn void DSettingsBackend::sync();
  * \brief private signal, please do not use it.
@@ -388,7 +388,11 @@ QList<QPointer<DSettingsOption> > DSettings::options() const
 
 QVariant DSettings::getOption(const QString &key) const
 {
-    return option(key)->value();
+    QPointer<DSettingsOption> optionPointer = option(key);
+    if (optionPointer) {
+        return optionPointer->value();
+    }
+    return QVariant();
 }
 
 void DSettings::setOption(const QString &key, const QVariant &value)
